@@ -1,10 +1,11 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
- * Copyright (c) 2009 Thomas Schmitt
+ * Copyright (c) 2009 - 2012 Thomas Schmitt
  * 
  * This file is part of the libisofs project; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License version 2 as 
- * published by the Free Software Foundation. See COPYING file for details.
+ * modify it under the terms of the GNU General Public License version 2 
+ * or later as published by the Free Software Foundation. 
+ * See COPYING file for details.
  */
 #ifndef LIBISO_IMAGE_H_
 #define LIBISO_IMAGE_H_
@@ -52,6 +53,19 @@ struct Iso_Image
     /* el-torito boot catalog */
     struct el_torito_boot_catalog *bootcat;
 
+    /* Eventually loaded system area data, or NULL */
+    char *system_area_data;
+    /* Prescribed/detected options, see iso_write_opts_set_system_area() */
+    int system_area_options;
+
+   /*
+    * Up to 15 boot files can be referred by a MIPS Big Endian Volume Header.
+      The mips_boot_file_paths are ISO 9660 Rock Ridge paths.
+    */
+    int num_mips_boot_files;
+    char *mips_boot_file_paths[15]; /* ISO 9660 Rock Ridge Paths */
+
+
     /* image identifier, for message origin identifier */
     int id;
 
@@ -148,8 +162,6 @@ struct Iso_Image
     uint8_t *used_inodes;
     ino_t used_inodes_start;
 
-#ifdef Libisofs_with_checksumS
-
     /**
      * Array of MD5 checksums as announced by xattr "isofs.ca" of the 
      * root node. Array element 0 contains an overall image checksum for the
@@ -162,7 +174,18 @@ struct Iso_Image
     uint32_t checksum_idx_count;
     char *checksum_array;
 
-#endif /* Libisofs_with_checksumS */
+    /**
+     * Whether a write run has been started by iso_image_create_burn_source()
+     * and has not yet been finished.
+     */
+    int generator_is_running;
+
+    /* Pointers to directories or files which shall be get a HFS+ blessing.
+     * libisofs/hfsplus.c et.al. will compare these pointers
+     * with the ->node pointer of Ecma119Nodes.
+     * See libisofs.h
+     */
+    IsoNode *hfsplus_blessed[ISO_HFSPLUS_BLESS_MAX];
 
 };
 
